# StudyUuid


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

## Example

```python
from bia_integrator_api.models.study_uuid import StudyUuid

# TODO update the JSON string below
json = "{}"
# create an instance of StudyUuid from a JSON string
study_uuid_instance = StudyUuid.from_json(json)
# print the JSON string representation of the object
print StudyUuid.to_json()

# convert the object into a dict
study_uuid_dict = study_uuid_instance.to_dict()
# create an instance of StudyUuid from a dict
study_uuid_form_dict = study_uuid.from_dict(study_uuid_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


